==> popup_maker-7.x-1.0.tar.gz: popup_maker/popup_maker_settings.tpl.php <==
<div id="sgpm-admin">
	<div class="sgpm-tabs">
		<div class="sgpm-tabs-toolbar">
			<?php if ($edit === true): ?>
				<div class="sgpm-tab"><?php echo t('Edit Popup'); ?></div>
			<?php endif;
			if(!empty($settings['user'])): ?>
				<div class="sgpm-tab"><?php echo t('Popups'); ?></div>
			<?php endif; ?>
			<div class="sgpm-tab"><?php echo t('Api Credentials'); ?></div>
			<div class="sgpm-tab"><?php echo t('Support'); ?></div>
		</div>
		<div class="sgpm-tabs-content">
			<?php
			if ($edit === true):
				print theme('popup_maker_edit_popup', array('settings' => $settings, 'token' => $token, 'editingPopupId' => $editingPopupId, 'displayRules' => $displayRules));
			endif;

			if(!empty($settings['user'])):
				print theme('popup_maker_popups', array('settings' => $settings, 'token' => $token));
			endif;

			print theme('popup_maker_api_credentials', array('settings' => $settings, 'token' => $token));
			?>

			<section id="sgpm-support-panel" class="sgpm-panel">
				<iframe width="100%" height="400" src="https://www.youtube.com/embed/ekSNAR2lScY?list=UUhtxsnAzUmv02GZhiL66Nwg" frameborder="0" gesture="media" allowfullscreen></iframe>
				<a href="<?php echo SGPM_SERVICE_URL.'help/kb/faq.php?id=32&title=How+to+Use+the+Popup+Maker+Plugin+in+WordPress%3F'; ?>" class="sgpm-support-block-box" target="_blank">
					<svg height="60" viewBox="0 0 24 24" width="60" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
						<defs>
							<path d="M0 0h24v24H0V0z" id="a"/>
						</defs>
						<clipPath id="b">
							<use overflow="visible" xlink:href="#a"/>
						</clipPath>
						<path clip-path="url(#b)" d="M9 21c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-1H9v1zm3-19C8.14 2 5 5.14 5 9c0 2.38 1.19 4.47 3 5.74V17c0 .55.45 1 1 1h6c.55 0 1-.45 1-1v-2.26c1.81-1.27 3-3.36 3-5.74 0-3.86-3.14-7-7-7zm2.85 11.1l-.85.6V16h-4v-2.3l-.85-.6C7.8 12.16 7 10.63 7 9c0-2.76 2.24-5 5-5s5 2.24 5 5c0 1.63-.8 3.16-2.15 4.1z"/>
					</svg>
					<p class="sgpm-support-block-box-title">Knowledgebase</p>
				</a>
				<a href="<?php echo SGPM_SERVICE_URL.'help/open.php'; ?>" class="sgpm-support-block-box" target="_blank">
					<svg height="60" viewBox="0 0 24 24" width="60" xmlns="http://www.w3.org/2000/svg">
						<path d="M2.01 21L23 12 2.01 3 2 10l15 2-15 2z"/>
						<path d="M0 0h24v24H0z" fill="none"/>
					</svg>
					<p class="sgpm-support-block-box-title">Open a New Ticket</p>
				</a>
			</section>
		</div>
	</div>
</div>

==> popup_maker-7.x-1.1.tar.gz: popup_maker/popup_maker_settings.tpl.php <==
<div id="sgpm-admin">
	<div class="sgpm-tabs">
		<div class="sgpm-tabs-toolbar">
			<?php if ($edit === true): ?>
				<div class="sgpm-tab"><?php echo t('Edit Popup'); ?></div>
			<?php endif;
			if(!empty($settings['user'])): ?>
				<div class="sgpm-tab"><?php echo t('Popups'); ?></div>
			<?php endif; ?>
			<div class="sgpm-tab"><?php echo t('Api Credentials'); ?></div>
			<div class="sgpm-tab"><?php echo t('Support'); ?></div>
		</div>
		<div class="sgpm-tabs-content">
			<?php
			if ($edit === true):
				print theme('popup_maker_edit_popup', array('settings' => $settings, 'token' => $token, 'editingPopupId' => $editingPopupId, 'displayRules' => $displayRules));
			endif;

			if(!empty($settings['user'])):
				print theme('popup_maker_popups', array('settings' => $settings, 'token' => $token));
			endif;

			print theme('popup_maker_api_credentials', array('settings' => $settings, 'token' => $token));
			?>

			<section id="sgpm-support-panel" class="sgpm-panel">
				<iframe width="100%" height="400" src="https://www.youtube.com/embed/jXv3Ugnkt-w?list=UUhtxsnAzUmv02GZhiL66Nwg" frameborder="0" gesture="media" allowfullscreen></iframe>
				<a href="<?php echo SGPM_SERVICE_URL.'help/kb/faq.php?id=32&title=How+to+Use+the+Popup+Maker+Plugin+in+WordPress%3F'; ?>" class="sgpm-support-block-box" target="_blank">
					<svg height="60" viewBox="0 0 24 24" width="60" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
						<defs>
							<path d="M0 0h24v24H0V0z" id="a"/>
						</defs>
						<clipPath id="b">
							<use overflow="visible" xlink:href="#a"/>
						</clipPath>
						<path clip-path="url(#b)" d="M9 21c0 .55.45 1 1 1h4c.55 0 1-.45 1-1v-1H9v1zm3-19C8.14 2 5 5.14 5 9c0 2.38 1.19 4.47 3 5.74V17c0 .55.45 1 1 1h6c.55 0 1-.45 1-1v-2.26c1.81-1.27 3-3.36 3-5.74 0-3.86-3.14-7-7-7zm2.85 11.1l-.85.6V16h-4v-2.3l-.85-.6C7.8 12.16 7 10.63 7 9c0-2.76 2.24-5 5-5s5 2.24 5 5c0 1.63-.8 3.16-2.15 4.1z"/>
					</svg>
					<p class="sgpm-support-block-box-title">Knowledgebase</p>
				</a>
				<a href="<?php echo SGPM_SERVICE_URL.'help/open.php'; ?>" class="sgpm-support-block-box" target="_blank">
					<svg height="60" viewBox="0 0 24 24" width="60" xmlns="http://www.w3.org/2000/svg">
						<path d="M2.01 21L23 12 2.01 3 2 10l15 2-15 2z"/>
						<path d="M0 0h24v24H0z" fill="none"/>
					</svg>
					<p class="sgpm-support-block-box-title">Open a New Ticket</p>
				</a>
			</section>
		</div>
	</div>
</div>
